==> arg-services-1.1.0-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/AdaptationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.52.1)",
    comments = "Source: arg_services/cbr/v1beta/adaptation.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AdaptationServiceGrpc {

  private AdaptationServiceGrpc() {}

  public static final String SERVICE_NAME = "arg_services.cbr.v1beta.AdaptationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Adapt",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest, de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod;
    if ((getAdaptMethod = AdaptationServiceGrpc.getAdaptMethod) == null) {
      synchronized (AdaptationServiceGrpc.class) {
        if ((getAdaptMethod = AdaptationServiceGrpc.getAdaptMethod) == null) {
          AdaptationServiceGrpc.getAdaptMethod = getAdaptMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest, de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Adapt"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AdaptationServiceMethodDescriptorSupplier("Adapt"))
              .build();
        }
      }
    }
    return getAdaptMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AdaptationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceStub>() {
        @java.lang.Override
        public AdaptationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceStub(channel, callOptions);
        }
      };
    return AdaptationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AdaptationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingStub>() {
        @java.lang.Override
        public AdaptationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceBlockingStub(channel, callOptions);
        }
      };
    return AdaptationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AdaptationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceFutureStub>() {
        @java.lang.Override
        public AdaptationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceFutureStub(channel, callOptions);
        }
      };
    return AdaptationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class AdaptationServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getAdaptMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getAdaptMethod(),
            io.grpc.stub.ServerCalls.asyncUnaryCall(
              new MethodHandlers<
                de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
                de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>(
                  this, METHODID_ADAPT)))
          .build();
    }
  }

  /**
   */
  public static final class AdaptationServiceStub extends io.grpc.stub.AbstractAsyncStub<AdaptationServiceStub> {
    private AdaptationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceStub(channel, callOptions);
    }

    /**
     */
    public void adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getAdaptMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class AdaptationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<AdaptationServiceBlockingStub> {
    private AdaptationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getAdaptMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class AdaptationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<AdaptationServiceFutureStub> {
    private AdaptationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> adapt(
        de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getAdaptMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ADAPT = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AdaptationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(AdaptationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ADAPT:
          serviceImpl.adapt((de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class AdaptationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AdaptationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.AdaptationProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AdaptationService");
    }
  }

  private static final class AdaptationServiceFileDescriptorSupplier
      extends AdaptationServiceBaseDescriptorSupplier {
    AdaptationServiceFileDescriptorSupplier() {}
  }

  private static final class AdaptationServiceMethodDescriptorSupplier
      extends AdaptationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    AdaptationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AdaptationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AdaptationServiceFileDescriptorSupplier())
              .addMethod(getAdaptMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> arg-services-1.5.9-sources.jar: de/uni_trier/recap/arg_services/cbr/v1beta/AdaptationServiceGrpc.java <==
package de.uni_trier.recap.arg_services.cbr.v1beta;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.71.0)",
    comments = "Source: arg_services/cbr/v1beta/adaptation.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class AdaptationServiceGrpc {

  private AdaptationServiceGrpc() {}

  public static final java.lang.String SERVICE_NAME = "arg_services.cbr.v1beta.AdaptationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Adapt",
      requestType = de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest.class,
      responseType = de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
      de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod() {
    io.grpc.MethodDescriptor<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest, de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> getAdaptMethod;
    if ((getAdaptMethod = AdaptationServiceGrpc.getAdaptMethod) == null) {
      synchronized (AdaptationServiceGrpc.class) {
        if ((getAdaptMethod = AdaptationServiceGrpc.getAdaptMethod) == null) {
          AdaptationServiceGrpc.getAdaptMethod = getAdaptMethod =
              io.grpc.MethodDescriptor.<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest, de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Adapt"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse.getDefaultInstance()))
              .setSchemaDescriptor(new AdaptationServiceMethodDescriptorSupplier("Adapt"))
              .build();
        }
      }
    }
    return getAdaptMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static AdaptationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceStub>() {
        @java.lang.Override
        public AdaptationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceStub(channel, callOptions);
        }
      };
    return AdaptationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports all types of calls on the service
   */
  public static AdaptationServiceBlockingV2Stub newBlockingV2Stub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingV2Stub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingV2Stub>() {
        @java.lang.Override
        public AdaptationServiceBlockingV2Stub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceBlockingV2Stub(channel, callOptions);
        }
      };
    return AdaptationServiceBlockingV2Stub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static AdaptationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceBlockingStub>() {
        @java.lang.Override
        public AdaptationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceBlockingStub(channel, callOptions);
        }
      };
    return AdaptationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static AdaptationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<AdaptationServiceFutureStub>() {
        @java.lang.Override
        public AdaptationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new AdaptationServiceFutureStub(channel, callOptions);
        }
      };
    return AdaptationServiceFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default void adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getAdaptMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service AdaptationService.
   */
  public static abstract class AdaptationServiceImplBase
      implements io.grpc.BindableService, AsyncService {

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return AdaptationServiceGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service AdaptationService.
   */
  public static final class AdaptationServiceStub
      extends io.grpc.stub.AbstractAsyncStub<AdaptationServiceStub> {
    private AdaptationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceStub(channel, callOptions);
    }

    /**
     */
    public void adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request,
        io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncUnaryCall(
          getChannel().newCall(getAdaptMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service AdaptationService.
   */
  public static final class AdaptationServiceBlockingV2Stub
      extends io.grpc.stub.AbstractBlockingStub<AdaptationServiceBlockingV2Stub> {
    private AdaptationServiceBlockingV2Stub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceBlockingV2Stub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceBlockingV2Stub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getAdaptMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do limited synchronous rpc calls to service AdaptationService.
   */
  public static final class AdaptationServiceBlockingStub
      extends io.grpc.stub.AbstractBlockingStub<AdaptationServiceBlockingStub> {
    private AdaptationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse adapt(de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request) {
      return io.grpc.stub.ClientCalls.blockingUnaryCall(
          getChannel(), getAdaptMethod(), getCallOptions(), request);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service AdaptationService.
   */
  public static final class AdaptationServiceFutureStub
      extends io.grpc.stub.AbstractFutureStub<AdaptationServiceFutureStub> {
    private AdaptationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected AdaptationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new AdaptationServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse> adapt(
        de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest request) {
      return io.grpc.stub.ClientCalls.futureUnaryCall(
          getChannel().newCall(getAdaptMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_ADAPT = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_ADAPT:
          serviceImpl.adapt((de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest) request,
              (io.grpc.stub.StreamObserver<de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  public static final io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getAdaptMethod(),
          io.grpc.stub.ServerCalls.asyncUnaryCall(
            new MethodHandlers<
              de.uni_trier.recap.arg_services.cbr.v1beta.AdaptRequest,
              de.uni_trier.recap.arg_services.cbr.v1beta.AdaptResponse>(
                service, METHODID_ADAPT)))
        .build();
  }

  private static abstract class AdaptationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    AdaptationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return de.uni_trier.recap.arg_services.cbr.v1beta.AdaptationProto.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("AdaptationService");
    }
  }

  private static final class AdaptationServiceFileDescriptorSupplier
      extends AdaptationServiceBaseDescriptorSupplier {
    AdaptationServiceFileDescriptorSupplier() {}
  }

  private static final class AdaptationServiceMethodDescriptorSupplier
      extends AdaptationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    AdaptationServiceMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (AdaptationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new AdaptationServiceFileDescriptorSupplier())
              .addMethod(getAdaptMethod())
              .build();
        }
      }
    }
    return result;
  }
}
